@@ -558,7 +558,7 @@ class Distortion(object):
         :return:
         """
 
-        df = pd.DataFrame(index=np.linspace(0,1,10001), dtype=np.float)
+        df = pd.DataFrame(index=np.linspace(0,1,10001), dtype=float)
 
         for i in range(samples):
             rebit = data.sample(frac=proportion, replace=False, random_state=random_state)
@@ -754,4 +754,4 @@ class Distortion(object):
             return ans
         else:
             # no longer guaranteed that a is in ser.index
-            return ans.iloc[ans.index.get_loc(a, method='nearest')]
\ No newline at end of file
+            return ans.iloc[ans.index.get_loc(a, method='nearest')]
